@@ -13,12 +13,11 @@
 ##############################################################################
 """Address Book Views
 
-$Id: browser.py 111378 2010-04-24 17:30:08Z ccomb $
+$Id: browser.py 102109 2009-07-23 06:40:00Z srichter $
 """
 __docformat__ = "reStructuredText"
 import zope.component
 import zope.location
-from zope.app.container import btree
 from zope.session.interfaces import ISession
 from zope.pagetemplate.interfaces import IPageTemplate
 from zope.publisher import browser
@@ -97,7 +96,7 @@ class AddressesForm(form.AddForm):
         # container in a session variable.
         session = ISession(self.request)[SESSION_KEY]
         if 'addresses' not in session:
-            session['addresses'] = btree.BTreeContainer()
+            session['addresses'] = contact.Addresses()
         return session['addresses']
 
     def update(self):
@@ -382,6 +381,8 @@ class AddressBook(browser.BrowserPage):
             return session.get('selectedContact')
         def set(self, value):
             session = ISession(self.request)[SESSION_KEY]
+            # The session data is stored in the ZODB, so we must remove
+            # security proxies.
             session['selectedContact'] = removeSecurityProxy(value)
         return property(get, set)
 
